EasyExtend.langlets.p4d.langlet.InteractiveTransformer

Package EasyExtend :: Package langlets :: Package p4d :: Module langlet :: Class InteractiveTransformer |
[hide private]
[frames] | no frames]

# Class InteractiveTransformer

                   object --+
                            |
    eetransformer.Transformer --+
                                |
               LangletTransformer --+
                                    |
                                   InteractiveTransformer

Instance Methods | [hide private]
p4d_string(self, p4dnode) |
Inherited from `LangletTransformer`: `NAME`, `SPECNUM`, `build_p4d_attribute`, `build_p4d_compound_stmt`, `build_p4d_element`, `build_p4d_expr`, `build_p4d_name`, `build_p4d_simple_stmt`, `build_p4d_stmt`, `build_p4d_suite`, `p4d_accessor`, `p4d_attr_access`, `p4d_compound_stmt`, `subscript` Inherited from `eetransformer.Transformer`: `__init__`, `contains_node`, `general_transform`, `get_container`, `is_main`, `is_node`, `mark_node`, `node_stack`, `prepare`, `run`, `terminate`, `unmark_node` Inherited from `eetransformer.Transformer` (private): `_find_handler`, `_load_exospace` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### p4d_string(self, p4dnode) |
Overrides: LangletTransformer.p4d_string